@@ -8,7 +8,8 @@
 #' (for groundwater levels), "site" (for site service), and "qw" (water-quality). Note: "qw" calls go to: 
 #' \url{http://nwis.waterdata.usgs.gov/usa/nwis/qwdata} for data requests, and use different call requests schemes. 
 #' @param \dots see \url{http://waterservices.usgs.gov/rest/Site-Service.html#Service} for a complete list of options
-#' @keywords data import NWIS web service
+#' @import utils
+#' @import stats
 #' @return A data frame with the following columns:
 #' \tabular{lll}{
 #' Name \tab Type \tab Description \cr
@@ -74,6 +75,7 @@
 #'                   "drain_area_va","obs_count_nu"),service="qw")
 #' temp <- readNWISdata(bBox=c(-83,36.5,-81,38.5), parameterCd="00010", service="site", 
 #'                    seriesCatalogOutput=TRUE)
+#' wiGWL <- readNWISdata(stateCd="WI",service="gwlevels")
 #' }
 readNWISdata <- function(service="dv", ...){
   
@@ -152,7 +154,7 @@ readNWISdata <- function(service="dv", ...){
     tz <- ""
   }
   
-  if(service == "site"){
+  if(service %in% c("site","gwlevels")){
     format <- "rdb"
   }
   
@@ -161,14 +163,15 @@ readNWISdata <- function(service="dv", ...){
   baseURL <- paste0(baseURL,service,"/?format=",format,"&")
   urlCall <- paste0(baseURL,urlCall)
   
-  if(service == "site"){
+  if(format == "rdb"){
     possibleError <- tryCatch({
-      retval <- importRDB1(urlCall, asDateTime = FALSE, qw = FALSE, tz = tz)
+      retval <- importRDB1(urlCall, asDateTime = (service == "qwdata"), 
+                           qw = (service == "qwdata"), tz = tz)
     }, error = function(e) {
       stop(e, "with url:", urlCall)
     })
     
-  } else if (service != "qwdata") {
+  } else {
     possibleError <- tryCatch({
       retval <- importWaterML1(urlCall, asDateTime = ("iv" == service), tz= tz)
     }, error = function(e) {
@@ -201,12 +204,6 @@ readNWISdata <- function(service="dv", ...){
       }
     }
     
-  } else {
-    possibleError <- tryCatch({
-      retval <- importRDB1(urlCall, asDateTime = TRUE, qw = TRUE)
-    }, error = function(e) {
-      stop(e, "with url:", urlCall)
-    })
   }
   
   return(retval)
